| Title: | Unicode Extensions for the 'rebus' Package |
|---|---|
| Description: | Build regular expressions piece by piece using human readable code. This package contains Unicode functionality, and is primarily intended to be used by package developers. |
| Authors: | Richard Cotton [aut, cre] |
| Maintainer: | Richard Cotton <[email protected]> |
| License: | Unlimited |
| Version: | 0.0-3 |
| Built: | 2026-05-08 05:05:05 UTC |
| Source: | https://github.com/richierocks/rebus.unicode |